@@ -1,3 +1,4 @@
+use super::to_string_radix;
 use crate::Serialer;
 use chrono::{DateTime, Datelike, Duration, Local, TimeZone, Timelike};
 use std::fmt::{Debug, Formatter};
@@ -297,45 +298,6 @@ fn format_u16(n: u16, decimal_only: bool) -> String {
     }
 }
 
-#[inline]
-fn to_string_radix(mut n: usize, radix: usize, size: usize, digit_first: bool) -> String {
-    assert!(radix >= 2 && radix <= 36);
-
-    let bytes_table: [char; 36] = if digit_first {
-        [
-            '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F', 'G',
-            'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X',
-            'Y', 'Z',
-        ]
-    } else {
-        [
-            'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q',
-            'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '0', '1', '2', '3', '4', '5', '6', '7',
-            '8', '9',
-        ]
-    };
-
-    let mut buf = String::with_capacity(2);
-
-    loop {
-        let m = n % radix;
-        n = n / radix;
-        buf.push(bytes_table[m]);
-        if n == 0 {
-            break;
-        }
-    }
-
-    use std::cmp;
-    (0..(size - cmp::min(size, buf.len()))).for_each(|_| buf.push(bytes_table[0]));
-
-    unsafe {
-        buf.as_mut_vec().reverse();
-    }
-
-    buf
-}
-
 fn build_head(dt: &DateTime<Local>) -> String {
     const OFFSET: i32 = 1918;
     format!(
